==> dde-launcher_4.4.5.5.orig.tar.xz: dde-launcher-4.4.5.5/translations/dde-launcher_hr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hr" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>Nema rezultata pretrage</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Game</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Office</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Others</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Jeste li sigurni da želite deinstalirati %1 ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Otkaži</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potvrdi</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Ukloni s radne površine</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Ukloni sa sidrišta</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Deinstaliraj</translation>
    </message>
    <message>
        <source>Open by proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open</source>
        <translation>Otvori</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Send to dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add to startup</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>Svi programi</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Razgovor</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Glazba</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafika</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Igra</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Ured</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Čitanje</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Razvojni alati</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sustav</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Ostalo</translation>
    </message>
</context>
<context>
    <name>MiniFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Jeste li sigurni da želite deinstalirati %1 ?</translation>
    </message>
    <message>
        <source>All dependencies will be removed together</source>
        <translation>Sve će zavisnosti biti uklonjene zajedno</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Otkaži</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potvrdi</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Računalo</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenti</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video datoteke</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Glazba</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Slike</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Preuzimanja</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zaključaj</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Odjava</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Ponovno podigni sustav</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspendiraj</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Isključi</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Natrag</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Računalo</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Glazba</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Isključi</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zaključaj</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Odjava</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Ponovno podigni sustav</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspendiraj</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Natrag</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenti</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video datoteke</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Slike</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Preuzimanja</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Računalo</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Glazba</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Preuzimanja</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ručno</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Postavke</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Isključi</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video datoteke</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Slike</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Traži</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Jeste li sigurni da želite deinstalirati %1 ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Otkaži</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potvrdi</translation>
    </message>
</context>
</TS>

==> dde-launcher_5.0.14.orig.tar.xz: dde-launcher-5.0.14/translations/dde-launcher_hr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hr" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>Nema rezultata pretrage</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Razgovor</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Glazba</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafika</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Ured</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Čitanje</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Razvojni alati</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sustav</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>Igre</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Ostalo</translation>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Otkaži</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potvrdi</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Ukloni s radne površine</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Ukloni sa sidrišta</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Deinstaliraj</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open</source>
        <translation>Otvori</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Pošalji na radnu površinu</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Ukloni iz početnih</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Dodaj u početne</translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>Svi programi</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Razgovor</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Glazba</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafika</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Igra</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Ured</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Čitanje</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Razvojni alati</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sustav</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Ostalo</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Računalo</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenti</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video datoteke</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Glazba</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Slike</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Preuzimanja</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zaključaj</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Odjava</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Ponovno podigni sustav</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspendiraj</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Isključi</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Natrag</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Računalo</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Glazba</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Isključi</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zaključaj</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Odjava</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Ponovno podigni sustav</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspendiraj</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Natrag</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenti</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video datoteke</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Slike</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Preuzimanja</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Računalo</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Glazba</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Preuzimanja</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ručno</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Postavke</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video datoteke</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Slike</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenti</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>Energija</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation>Sve kategorije</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Natrag</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Traži</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Otkaži</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potvrdi</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
